"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
exports.__esModule = true;
var case_1 = __importDefault(require("case"));
var lodash_1 = __importDefault(require("lodash"));
var name = 'object-prop-casing';
var rule = {
    name: name,
    check: function (swagger, ruleValue, fullConfig) {
        var _a, _b, _c;
        var errors = [];
        var validCases = ruleValue.reduce(function (acc, val) {
            acc[val] = null;
            return acc;
        }, {});
        lodash_1["default"].difference(Object.keys(swagger.definitions), (_c = (_b = (_a = fullConfig) === null || _a === void 0 ? void 0 : _a.ignore) === null || _b === void 0 ? void 0 : _b.definitions, (_c !== null && _c !== void 0 ? _c : []))).forEach(function (defKey) {
            var definition = swagger.definitions[defKey];
            if (definition.type === 'object') {
                if ('properties' in definition) {
                    Object.keys(definition.properties).forEach(function (propName) {
                        var propCase = case_1["default"].of(propName);
                        if (!(propCase in validCases)) {
                            errors.push({
                                msg: "Property \"" + propName + "\" has wrong casing on \"" + defKey + "\"",
                                name: name
                            });
                        }
                        var topLevelProp = definition.properties[propName];
                        // TODO dig deeper with a stack
                        if (topLevelProp.type === 'object') {
                            Object.keys(topLevelProp.properties || {}).forEach(function (k) {
                                var propCase = case_1["default"].of(propName);
                                if (!(propCase in validCases)) {
                                    errors.push({
                                        msg: "Property in path \"" + propName + "." + k + "\" has wrong casing on \"" + defKey + "\"",
                                        name: name
                                    });
                                }
                            });
                        }
                    });
                }
                else {
                    // handled by 'properties-for-object-type'
                }
            }
        });
        return errors;
    }
};
exports["default"] = rule;
