"use strict";
exports.__esModule = true;
var name = 'path-param-required-field';
var methods = [
    'get',
    'post',
    'put',
    'delete',
    'options',
    'trace',
];
function isRefObj(obj) {
    return (typeof obj === 'object' &&
        !Array.isArray(obj) &&
        obj !== null &&
        '$ref' in obj &&
        typeof obj.$ref === 'string');
}
var rule = {
    name: name,
    check: function (swagger) {
        var errors = [];
        Object.keys(swagger.paths).forEach(function (pathName) {
            var path = swagger.paths[pathName];
            if (path.parameters) {
                path.parameters.forEach(function (param) {
                    if (isRefObj(param)) {
                        // TODO handle refs
                        return;
                    }
                    if (typeof param.required !== 'boolean') {
                        errors.push({
                            name: name,
                            msg: "required is not set for path \"" + pathName + "\".parameters"
                        });
                    }
                });
            }
            methods.forEach(function (method) {
                var operation = path[method];
                if (operation === undefined)
                    return;
                console.log(operation);
                operation.parameters.forEach(function (param) {
                    if (isRefObj(param)) {
                        // TODO handle refs
                        return;
                    }
                    if (typeof param.required !== 'boolean') {
                        errors.push({
                            name: name,
                            msg: "required is not set for path \"" + pathName + "\" in \"" + method + "\" in \"" + param.name + "\""
                        });
                    }
                });
            });
        });
        return errors;
    }
};
exports["default"] = rule;
